# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.4.0] - 2021-10-19
### Added
- Support for python 3.10

### Changed

### Removed


[Unreleased]: https://github.com/klen/muffin-databases/compare/0.4.0...HEAD
[0.4.0]: https://github.com/klen/muffin-databases/compare/0.3.3...0.4.0
[0.3.3]: https://github.com/klen/muffin-databases/compare/0.2.6...0.3.3
[0.2.6]: https://github.com/klen/muffin-databases/compare/0.1.3...0.2.6
